Examples
========

The following examples give an idea of how to use EGTtools to model social dynamics:

.. toctree::

    Hawk and dove dynamics <examples/hawk_dove_dynamics>
    Hawk and dove dynamics with new PairwiseComparison class <examples/hawk_dove_dynamics_pairwise_comparison>
    Monte Carlo simulations <examples/normal_form_game_mc_simulations>
    Invasion diagram <examples/plot_invasion_diagram>
    2D Simplex plot <examples/plot_simplex>
    2D Simplex plot simplified <examples/plot_simplex_simplified>
    General examples <examples/examples_of_use>


Projects using EGTtools
--------------------------

The `EvoCRD <https://github.com/Socrats/EvoCRD>`_ provide an example of use of EGTtools do
model dynamics in the Collective Risk Dilemma.

You can also find all these examples and a bit more `here <https://github.com/Socrats/egt-tutorial>`_ or launch
the notebooks with `Binder <https://mybinder.org/v2/gh/Socrats/egt-tutorial/HEAD>`_.